( cd usr ; rm -rf man )
( cd usr ; ln -sf /cdrom/usr/man man )
( cd usr/X11R6/bin ; rm -rf xfilemanager )
( cd usr/X11R6/bin ; ln -sf /cdrom/usr/X11R6/bin/xfilemanager xfilemanager )
( cd usr/X11R6 ; rm -rf include )
( cd usr/X11R6 ; ln -sf /cdrom/usr/X11R6/include include )
